#ifndef _VOID_ACTION_H
#define _VOID_ACTION_H

#include "osl/piece.h"
namespace osl
{
  namespace move_action
  {
    /**
     * なにもしない.
     * 主にデバッグ用
     */
    class VoidAction {
    public:
      void simpleMove(Square, Square, Ptype, bool, Player,Move){
      }
      void unknownMove(Square, Square, Piece, Ptype, bool, Player,Move){
      }
      void dropMove(Square, Ptype, Player,Move){
      }
      void simpleMove(Square, Square, Ptype, bool, Player){
      }
      void unknownMove(Square, Square, Piece, Ptype, bool, Player){
      }
      void dropMove(Square, Ptype, Player){
      }
    };
  } // namespace move_action
} // namespace osl
#endif // _VOID_ACTION_H
// ;;; Local Variables:
// ;;; mode:c++
// ;;; c-basic-offset:2
// ;;; End:
